rnalysis.filtering.FoldChangeFilter.split\_by\_percentile
=========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.split_by_percentile